#include <stdio.h>
#include <string.h>

#include "shoehorn.h"
#include "serial.h"
#include "log.h"
#include "operation.h"
#include "extra_armadillo5x0.h"

#define START_CHAR	'<'
#define END_CHAR	'>'

struct loader_operations loader_ops = {
#if !defined(WIN32)
	.wait_wakeup	= NULL,
	.load		= NULL,
	.wait_ready	= NULL,
#else
	NULL, NULL, NULL
#endif
};

static int
loader_wait_wakeup_default(void)
{
	message("Waiting for target - press Wakeup now.\n");
	while (get_char() != START_CHAR) {
		if (shoehorn_cancel_check()) {
			return -1;
		}
	}
	return 0;
}

static int
loader_load_default(u8 *buf, u32 size)
{
	put_block(buf, size);
	return 0;
}

static int
loader_wait_ready_default(void)
{
	if (get_char() != END_CHAR){
		return -1;
	}
	return 0;
}

static void
loader_ops_setup_default(struct loader_operations *ops)
{
	ops->wait_wakeup	= loader_wait_wakeup_default;
	ops->load		= loader_load_default;
	ops->wait_ready		= loader_wait_ready_default;
}

int
loader_ops_init(char *id)
{
	if (id == NULL)
		id = "default";

	if (!strncmp(id, "armadillo5x0", 12)) {
		loader_ops_setup_armadillo5x0(&loader_ops);
	} else {
		/* default ops */
		loader_ops_setup_default(&loader_ops);
	}

	return 0;
}
